@@ -1,16 +1,23 @@
 <?php
-/* $Id: sql_query_form.lib.php 9156 2006-07-03 15:01:45Z cybot_tm $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * functions for displaying the sql query form
  *
+ * @version $Id: sql_query_form.lib.php 12280 2009-03-03 15:19:48Z lem9 $
  * @usedby  server_sql.php
- * @usedby  db_details.php
- * @usedby  tbl_properties.php
- * @usedby  tbl_properties_structure.php
+ * @usedby  db_sql.php
+ * @usedby  tbl_sql.php
+ * @usedby  tbl_structure.php
  * @usedby  querywindow.php
+ * @package phpMyAdmin
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
+/**
+ *
+ */
 require_once './libraries/file_listing.php'; // used for file listing
 require_once './libraries/bookmark.lib.php'; // used for file listing
 
@@ -18,15 +25,15 @@ require_once './libraries/bookmark.lib.php'; // used for file listing
  * prints the sql query boxes
  *
  * @usedby  server_sql.php
- * @usedby  db_details.php
- * @usedby  tbl_properties.php
- * @usedby  tbl_properties_structure.php
+ * @usedby  db_sql.php
+ * @usedby  tbl_sql.php
+ * @usedby  tbl_structure.php
  * @usedby  querywindow.php
  * @uses    $GLOBALS['table']
  * @uses    $GLOBALS['db']
  * @uses    $GLOBALS['server']
  * @uses    $GLOBALS['goto']
- * @uses    $GLOBALS['is_upload']           from common.lib.php
+ * @uses    $GLOBALS['is_upload']           from common.inc.php
  * @uses    $GLOBALS['sql_query']           from grab_globals.lib.php
  * @uses    $GLOBALS['cfg']['DefaultQueryTable']
  * @uses    $GLOBALS['cfg']['DefaultQueryDatabase']
@@ -34,8 +41,7 @@ require_once './libraries/bookmark.lib.php'; // used for file listing
  * @uses    $GLOBALS['cfg']['DefaultTabDatabase']
  * @uses    $GLOBALS['cfg']['DefaultQueryDatabase']
  * @uses    $GLOBALS['cfg']['DefaultQueryTable']
- * @uses    $GLOBALS['cfg']['Bookmark']['db']
- * @uses    $GLOBALS['cfg']['Bookmark']['table']
+ * @uses    $GLOBALS['cfg']['Bookmark']
  * @uses    $GLOBALS['strSuccess']
  * @uses    PMA_generate_common_url()
  * @uses    PMA_backquote()
@@ -57,8 +63,9 @@ require_once './libraries/bookmark.lib.php'; // used for file listing
  * @param   boolean|string  $display_tab    sql|files|history|full|FALSE
  *                                          what part to display
  *                                          false if not inside querywindow
+ * @param   string          $delimiter
  */
-function PMA_sqlQueryForm($query = true, $display_tab = false)
+function PMA_sqlQueryForm($query = true, $display_tab = false, $delimiter = ';')
 {
     // check tab to display if inside querywindow
     if (! $display_tab) {
@@ -70,7 +77,7 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
 
     // query to show
     if (true === $query) {
-        $query = empty($GLOBALS['sql_query']) ? '' : $GLOBALS['sql_query'];
+        $query = $GLOBALS['sql_query'];
     }
 
     // set enctype to multipart for file uploads
@@ -82,20 +89,20 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
 
     $table  = '';
     $db     = '';
-    if (! isset($GLOBALS['db']) || ! strlen($GLOBALS['db'])) {
+    if (! strlen($GLOBALS['db'])) {
         // prepare for server related
         $goto   = empty($GLOBALS['goto']) ?
                     'server_sql.php' : $GLOBALS['goto'];
-    } elseif (! isset($GLOBALS['table']) || ! strlen($GLOBALS['table'])) {
+    } elseif (! strlen($GLOBALS['table'])) {
         // prepare for db related
         $db     = $GLOBALS['db'];
         $goto   = empty($GLOBALS['goto']) ?
-                    'db_details.php' : $GLOBALS['goto'];
+                    'db_sql.php' : $GLOBALS['goto'];
     } else {
         $table  = $GLOBALS['table'];
         $db     = $GLOBALS['db'];
         $goto   = empty($GLOBALS['goto']) ?
-                    'tbl_properties.php' : $GLOBALS['goto'];
+                    'tbl_sql.php' : $GLOBALS['goto'];
     }
 
 
@@ -105,9 +112,9 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
         <form method="post" id="sqlqueryform" target="frame_content"
               action="import.php"<?php echo $enctype; ?> name="sqlform"
               onsubmit="var save_name = window.opener.parent.frame_content.name;
-                        window.opener.parent.frame_content.name = save_name + '<?php echo time(); ?>';
-                        this.target = window.opener.parent.frame_content.name;
-                        return checkSqlQuery( this );" >
+              window.opener.parent.frame_content.name = save_name + '<?php echo time(); ?>';
+              this.target = window.opener.parent.frame_content.name;
+              return checkSqlQuery(this)">
         <?php
     } else {
         echo '<form method="post" action="import.php" ' . $enctype . ' id="sqlqueryform"'
@@ -134,7 +141,7 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
 
     // display querybox
     if ($display_tab === 'full' || $display_tab === 'sql') {
-        PMA_sqlQueryFormInsert($query, $is_querywindow);
+        PMA_sqlQueryFormInsert($query, $is_querywindow, $delimiter);
     }
 
     // display uploads
@@ -144,9 +151,7 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
 
     // Bookmark Support
     if ($display_tab === 'full' || $display_tab === 'history') {
-        if (! empty( $GLOBALS['cfg']['Bookmark'])
-          && $GLOBALS['cfg']['Bookmark']['db']
-          && $GLOBALS['cfg']['Bookmark']['table']) {
+        if (! empty($GLOBALS['cfg']['Bookmark'])) {
             PMA_sqlQueryFormBookmark();
         }
     }
@@ -159,7 +164,7 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
     echo '</form>' . "\n";
     if ($is_querywindow) {
         ?>
-        <script type="text/javascript" language="javascript">
+        <script type="text/javascript">
         //<![CDATA[
             if (window.opener) {
                 window.opener.parent.insertQuery();
@@ -180,21 +185,20 @@ function PMA_sqlQueryForm($query = true, $display_tab = false)
  * @uses    $GLOBALS['cfg']['TextareaRows']
  * @uses    $GLOBALS['strShowThisQuery']
  * @uses    $GLOBALS['strGo']
- * @uses    PMA_availableDatabases()
  * @uses    PMA_USR_OS
  * @uses    PMA_USR_BROWSER_AGENT
  * @uses    PMA_USR_BROWSER_VER
- * @uses    PMA_availableDatabases()
  * @uses    htmlspecialchars()
  * @param   string      $query          query to display in the textarea
  * @param   boolean     $is_querywindow if inside querywindow or not
+ * @param   string      $delimiter      default delimiter to use
  */
-function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
+function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false, $delimiter = ';')
 {
 
     // enable auto select text in textarea
     if ($GLOBALS['cfg']['TextareaAutoSelect']) {
-        $auto_sel = ' onfocus="selectContent( this, sql_box_locked, true )"';
+        $auto_sel = ' onfocus="selectContent(this, sql_box_locked, true)"';
     } else {
         $auto_sel = '';
     }
@@ -203,19 +207,21 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
     if ($is_querywindow) {
         $locking = ' onkeypress="document.sqlform.elements[\'LockFromUpdate\'].'
             .'checked = true;"';
+        $height = $GLOBALS['cfg']['TextareaRows'] * 1.25;
     } else {
         $locking = '';
+        $height = $GLOBALS['cfg']['TextareaRows'] * 2;
     }
 
     $table          = '';
     $db             = '';
     $fields_list    = array();
-    if (! isset($GLOBALS['db']) || ! strlen($GLOBALS['db'])) {
+    if (! strlen($GLOBALS['db'])) {
         // prepare for server related
         $legend = sprintf($GLOBALS['strRunSQLQueryOnServer'],
-            htmlspecialchars(
-                $GLOBALS['cfg']['Servers'][$GLOBALS['server']]['host']));
-    } elseif (! isset($GLOBALS['table']) || ! strlen($GLOBALS['table'])) {
+            '&quot;' . htmlspecialchars(
+                ! empty($GLOBALS['cfg']['Servers'][$GLOBALS['server']]['verbose']) ? $GLOBALS['cfg']['Servers'][$GLOBALS['server']]['verbose'] : $GLOBALS['cfg']['Servers'][$GLOBALS['server']]['host']) . '&quot;');
+    } elseif (! strlen($GLOBALS['table'])) {
         // prepare for db related
         $db     = $GLOBALS['db'];
         // if you want navigation:
@@ -264,7 +270,7 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
                 str_replace('%d', PMA_backquote($db),
                     str_replace('%t', PMA_backquote($table),
                         str_replace('%f',
-                            implode(', ', $field_names ),
+                            implode(', ', $field_names),
                             $GLOBALS['cfg']['DefaultQueryTable'])));
             unset($field_names);
         }
@@ -285,7 +291,7 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
     echo '<div id="' . $sqlquerycontainer_id . '">' . "\n"
         .'<textarea name="sql_query" id="sqlquery"'
         .'  cols="' . $GLOBALS['cfg']['TextareaCols'] . '"'
-        .'  rows="' . $GLOBALS['cfg']['TextareaRows'] . '"'
+        .'  rows="' . $height . '"'
         .'  dir="' . $GLOBALS['text_dir'] . '"'
         .$auto_sel . $locking . '>' . htmlspecialchars($query) . '</textarea>' . "\n";
     echo '</div>' . "\n";
@@ -302,11 +308,11 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
             if (isset($field['Field']) && strlen($field['Field']) && isset($field['Comment'])) {
                 echo ' title="' . htmlspecialchars($field['Comment']) . '"';
             }
-            echo '>' . htmlspecialchars( $field['Field'] ) . '</option>' . "\n";
+            echo '>' . htmlspecialchars($field['Field']) . '</option>' . "\n";
         }
         echo '</select>' . "\n"
             .'<div id="tablefieldinsertbuttoncontainer">' . "\n";
-        if ( $GLOBALS['cfg']['PropertiesIconic'] ) {
+        if ($GLOBALS['cfg']['PropertiesIconic']) {
             echo '<input type="button" name="insert" value="&lt;&lt;"'
                 .' onclick="insertValueQuery()"'
                 .' title="' . $GLOBALS['strInsert'] . '" />' . "\n";
@@ -322,9 +328,7 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
     echo '<div class="clearfloat"></div>' . "\n";
     echo '</div>' . "\n";
 
-    if (! empty($GLOBALS['cfg']['Bookmark'])
-      && $GLOBALS['cfg']['Bookmark']['db']
-      && $GLOBALS['cfg']['Bookmark']['table']) {
+    if (! empty($GLOBALS['cfg']['Bookmark'])) {
         ?>
         <div id="bookmarkoptions">
         <div class="formelement">
@@ -356,7 +360,7 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
     echo '<div class="formelement">' . "\n";
     if ($is_querywindow) {
         ?>
-        <script type="text/javascript" language="javascript">
+        <script type="text/javascript">
         //<![CDATA[
             document.writeln(' <input type="checkbox" name="LockFromUpdate" value="1" id="checkbox_lock" /> <label for="checkbox_lock"><?php echo $GLOBALS['strQueryWindowLock']; ?></label> ');
         //]]>
@@ -365,12 +369,11 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
     }
     echo '</div>' . "\n";
     echo '<div class="formelement">' . "\n";
-    if (PMA_MYSQL_INT_VERSION >= 50000) {
-        echo '<label for="id_sql_delimiter">[ ' . $GLOBALS['strDelimiter']
-            .'</label>' . "\n";
-        echo '<input type="text" name="sql_delimiter" size="3" value=";" '
-            .'id="id_sql_delimiter" /> ]' . "\n";
-    }
+    echo '<label for="id_sql_delimiter">[ ' . $GLOBALS['strDelimiter']
+        .'</label>' . "\n";
+    echo '<input type="text" name="sql_delimiter" size="3" '
+        .'value="' . $delimiter . '" '
+        .'id="id_sql_delimiter" /> ]' . "\n";
 
     echo '<input type="checkbox" name="show_query" value="1" '
         .'id="checkbox_show_query" checked="checked" />' . "\n"
@@ -388,10 +391,9 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
  * prints bookmark fieldset
  *
  * @usedby  PMA_sqlQueryForm()
- * @uses    PMA_listBookmarks()
+ * @uses    PMA_Bookmark_getList()
  * @uses    $GLOBALS['db']
  * @uses    $GLOBALS['pmaThemeImage']
- * @uses    $GLOBALS['cfg']['Bookmark']
  * @uses    $GLOBALS['cfg']['ReplaceHelpImg']
  * @uses    $GLOBALS['strBookmarkQuery']
  * @uses    $GLOBALS['strBookmarkView']
@@ -405,7 +407,7 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false)
  */
 function PMA_sqlQueryFormBookmark()
 {
-    $bookmark_list = PMA_listBookmarks(isset($GLOBALS['db']) ? $GLOBALS['db'] : '', $GLOBALS['cfg']['Bookmark'] );
+    $bookmark_list = PMA_Bookmark_getList($GLOBALS['db']);
     if (! $bookmark_list || count($bookmark_list) < 1) {
         return;
     }
@@ -415,7 +417,7 @@ function PMA_sqlQueryFormBookmark()
     echo $GLOBALS['strBookmarkQuery'] . '</legend>' . "\n";
     echo '<div class="formelement">';
     echo '<select name="id_bookmark">' . "\n";
-    echo '<option value=""></option>' . "\n";
+    echo '<option value="">&nbsp;</option>' . "\n";
     foreach ($bookmark_list as $key => $value) {
         echo '<option value="' . htmlspecialchars($key) . '">'
             .htmlspecialchars($value) . '</option>' . "\n";
@@ -470,7 +472,6 @@ function PMA_sqlQueryFormBookmark()
  * @uses    $GLOBALS['cfg']['UploadDir']
  * @uses    $GLOBALS['cfg']['AvailableCharsets']
  * @uses    $GLOBALS['cfg']['AllowAnywhereRecoding']
- * @uses    $GLOBALS['strAutodetect']
  * @uses    $GLOBALS['strBzip']
  * @uses    $GLOBALS['strCharsetOfFile']
  * @uses    $GLOBALS['strCompression']
@@ -480,7 +481,6 @@ function PMA_sqlQueryFormBookmark()
  * @uses    $GLOBALS['strLocationTextfile']
  * @uses    $GLOBALS['strWebServerUploadDirectory']
  * @uses    $GLOBALS['strWebServerUploadDirectoryError']
- * @uses    $GLOBALS['allow_recoding']
  * @uses    $GLOBALS['charset']
  * @uses    $GLOBALS['max_upload_size']
  * @uses    PMA_supportedDecompressions()
@@ -488,7 +488,6 @@ function PMA_sqlQueryFormBookmark()
  * @uses    PMA_displayMaximumUploadSize()
  * @uses    PMA_generateCharsetDropdownBox()
  * @uses    PMA_generateHiddenMaxFileSize()
- * @uses    PMA_MYSQL_INT_VERSION
  * @uses    PMA_CSDROPDOWN_CHARSET
  * @uses    empty()
  */
@@ -515,7 +514,7 @@ function PMA_sqlQueryFormUpload(){
     echo '</div>';
 
     if ($files === FALSE) {
-        $errors[$GLOBALS['strError']] = $GLOBALS['strWebServerUploadDirectoryError'];
+        $errors[] = PMA_Message::error('strWebServerUploadDirectoryError');
     } elseif (!empty($files)) {
         echo '<div class="formelement">';
         echo '<strong>' . $GLOBALS['strWebServerUploadDirectory'] .':</strong>' . "\n";
@@ -531,32 +530,16 @@ function PMA_sqlQueryFormUpload(){
 
 
     echo '<fieldset id="" class="tblFooters">';
-    if ( PMA_MYSQL_INT_VERSION < 40100
-      && $GLOBALS['cfg']['AllowAnywhereRecoding']
-      && $GLOBALS['allow_recoding'] ) {
-        echo $GLOBALS['strCharsetOfFile'] . "\n"
-             . '<select name="charset_of_file" size="1">' . "\n";
-        foreach ($GLOBALS['cfg']['AvailableCharsets'] as $temp_charset) {
-            echo '<option value="' . $temp_charset . '"';
-            if ($temp_charset == $GLOBALS['charset']) {
-                echo ' selected="selected"';
-            }
-            echo '>' . $temp_charset . '</option>' . "\n";
-        }
-        echo '</select>' . "\n";
-    } elseif (PMA_MYSQL_INT_VERSION >= 40100) {
-        echo $GLOBALS['strCharsetOfFile'] . "\n";
-        echo PMA_generateCharsetDropdownBox(PMA_CSDROPDOWN_CHARSET,
-                'charset_of_file', null, 'utf8', FALSE);
-    } // end if (recoding)
+    echo $GLOBALS['strCharsetOfFile'] . "\n";
+    echo PMA_generateCharsetDropdownBox(PMA_CSDROPDOWN_CHARSET,
+            'charset_of_file', null, 'utf8', FALSE);
     echo '<input type="submit" name="SQL" value="' . $GLOBALS['strGo']
         .'" />' . "\n";
     echo '<div class="clearfloat"></div>' . "\n";
     echo '</fieldset>';
 
-    foreach ( $errors as $error => $message ) {
-        echo '<div>' . $error . '</div>';
-        echo '<div>' . $message . '</div>';
+    foreach ($errors as $error) {
+        $error->display();
     }
 }
 ?>
